@@ -1,7 +1,9 @@
+mod add_extra_data_hash;
 mod add_number_hash_mapping;
 mod cell;
 mod table_to_struct;
 
+pub use add_extra_data_hash::AddExtraDataHash;
 pub use add_number_hash_mapping::AddNumberHashMapping;
 pub use cell::CellMigration;
 pub use table_to_struct::ChangeMoleculeTableToStruct;
